@@ -149,17 +149,17 @@
     if (what == "z") {
         if (models$normal[j]) 
             return(tr)
-        return(qnorm(tmp$todistr$p(tr, log = TRUE), log.p = TRUE))
+        return(qnorm(tmp$todistr$p(tr, log.p = TRUE), log.p = TRUE))
     }
     if (what == "zleft") {
         if (models$normal[[j]])
             return(trl)
-        return(qnorm(tmp$todistr$p(trl, log = TRUE), log.p = TRUE))
+        return(qnorm(tmp$todistr$p(trl, log.p = TRUE), log.p = TRUE))
     }
     if (what == "dzleft") {
         if (models$normal[[j]])
             return(rep(1, length(trl)))
-        qn <- qnorm(tmp$todistr$p(trl, log = TRUE), log.p = TRUE)
+        qn <- qnorm(tmp$todistr$p(trl, log.p = TRUE), log.p = TRUE)
         dn <- dnorm(qn)
         dn[!is.finite(dn)] <- 1
         return(tmp$todistr$d(trl) / dn)
@@ -167,12 +167,12 @@
    if (what == "zright") {
         if (models$normal[[j]])
             return(trr)
-        return(qnorm(tmp$todistr$p(trr, log = TRUE), log.p = TRUE))
+        return(qnorm(tmp$todistr$p(trr, log.p = TRUE), log.p = TRUE))
     }
     if (what == "dzright") {
         if (models$normal[[j]])
             return(rep(1, length(trr)))
-        qn <- qnorm(tmp$todistr$p(trr, log = TRUE), log.p = TRUE)
+        qn <- qnorm(tmp$todistr$p(trr, log.p = TRUE), log.p = TRUE)
         dn <- dnorm(qn)
         dn[!is.finite(dn)] <- 1
         return(tmp$todistr$d(trr) / dn)
@@ -180,7 +180,7 @@
     if (what == "zprime") {
         if (models$normal[[j]])
             return(trp)
-        qn <- qnorm(tmp$todistr$p(tr, log = TRUE), log.p = TRUE)
+        qn <- qnorm(tmp$todistr$p(tr, log.p = TRUE), log.p = TRUE)
         return(trd / dnorm(qn))
     }
     if (what == "estfun") {
@@ -220,7 +220,7 @@
     ### fixed = FALSE?
     margin_par <- do.call("c", lapply(m$models, 
                                       function(mod) coef(as.mlt(mod))))
-    names(margin_par) <- paste(rep(Jnames, time = m$nparm), 
+    names(margin_par) <- paste(rep(Jnames, times = m$nparm), 
                                names(margin_par), sep = ".")
 
     rn <- rownames(unclass(ltMatrices(1:Jp, names = Jnames, byrow = TRUE)))
@@ -385,7 +385,7 @@
                                    Lambda = Lambda))
         }
         return(ret + llsc$logLik(obs = z, lower = lower, upper = upper, 
-                           Lambda = Lambda))
+                                 Lambda = Lambda))
     }
 
     sc <- function(parm, newdata = NULL) {
